@@ -28,6 +28,8 @@ const (
 	ArchitectureAMD64 = "amd64"
 	// ArchitectureS390X indicates s390x (IBM System Z).
 	ArchitectureS390X = "s390x"
+	// ArchitecturePPC64LE indicates ppc64 little endian (Power PC)
+	ArchitecturePPC64LE = "ppc64le"
 )
 
 // MachinePool is a pool of machines to be installed.
